job "web_static" {
  datacenters = ["dc1"]
  type = "service"

  constraint {
    attribute = "${attr.cpu.arch}"
    value     = "amd64"
  }

  group "landing" {
    network {
      port "deuxfleurs_port" { to = 8080 }
    }

    task "server" {
      driver = "docker"
      config {
        image = "superboum/amd64_webpull_pug:v4"
        ports = [ "deuxfleurs_port" ]
      }

      template {
        data = <<EOH
WEBPULL_REPO="https://git.deuxfleurs.fr/Deuxfleurs/site.git"
WEBPULL_TOKEN="{{ key "secrets/web/home_token" | trimSpace }}"
EOH
        destination = "secrets/env"
        env = true
      }

      resources {
        memory = 200
      }

      service {
        tags = [
          "webstatic",
          "traefik.enable=true",
          "traefik.frontend.entryPoints=https,http",
          "traefik.frontend.rule=Host:deuxfleurs.fr,www.deuxfleurs.fr,deuxfleurs.org,www.deuxfleurs.org;PathPrefix:/",
          # ideally we would have a rewrite regex: ^https?://(www\.deuxfleurs\.fr|deuxfleurs\.org|www\.deuxfleurs\.fr)(.*)$
          "traefik.frontend.priority=10"
        ]
        port = "deuxfleurs_port"
        address_mode = "host"
        name = "landing"
        check {
          type = "tcp"
          port = "deuxfleurs_port"
          interval = "60s"
          timeout = "5s"
          check_restart {
            limit = 3
            grace = "90s"
            ignore_warnings = false
          }
        }
      }
    }
  }

  group "quentin" {
    network {
      port "quentin_port" { to = 8080 }
    }

    task "server" {
      driver = "docker"
      config {
        image = "superboum/amd64_webpull_ruby:v1"
        ports = [ "quentin_port" ]
      }

      template {
        data = <<EOH
WEBPULL_REPO="https://git.deuxfleurs.fr/quentin/quentin.dufour.io.git"
WEBPULL_TOKEN="{{ key "secrets/web/quentin.dufour.io_token" | trimSpace }}"
EOH
        destination = "secrets/env"
        env = true
      }

      resources {
        memory = 500
      }

      service {
        tags = [
          "webstatic",
          "traefik.enable=true",
          "traefik.frontend.entryPoints=https",
          "traefik.frontend.rule=Host:quentin.dufour.io,www.quentin.dufour.io;PathPrefix:/"
        ]
        port = "quentin_port"
        address_mode = "host"
        name = "blog-quentin"
        check {
          type = "tcp"
          port = "quentin_port"
          interval = "60s"
          timeout = "5s"
          check_restart {
            limit = 3
            grace = "90s"
            ignore_warnings = false
          }
        }
      }
    }
  }
}

